@@ -4,11 +4,12 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.0903";
+our $VERSION = "2.10";
 
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
 use Carp;
+use List::Util qw(pairmap pairgrep);
 use Text::VisualWidth::PP 'vwidth';
 
 ######################################################################
@@ -86,11 +87,37 @@ our $DEFAULT_LINEBREAK = LINEBREAK_NONE;
 our $DEFAULT_RUNIN_WIDTH  = 2;
 our $DEFAULT_RUNOUT_WIDTH = 2;
 
-use charnames ':loose';
-my %tab_style = (
+use charnames ':full';
+our %TABSTYLE = (
+    pairmap {
+	( $a =~ s/_/-/gr, ref $b ? $b : [ $b, $b ] );
+    }
+    space  => [ ' ', ' ' ],
     dot    => [ '.', '.' ],
-    symbol => [ "\N{SYMBOL FOR HORIZONTAL TABULATION}", ' ' ],
-    shade  => [ "\N{MEDIUM SHADE}", "\N{LIGHT SHADE}" ],
+    symbol => [ "\N{SYMBOL FOR HORIZONTAL TABULATION}",
+		"\N{SYMBOL FOR SPACE}" ],
+    shade  => [ "\N{MEDIUM SHADE}",
+		"\N{LIGHT SHADE}" ],
+    block  => [ "\N{LOWER ONE QUARTER BLOCK}",
+		"\N{LOWER ONE EIGHTH BLOCK}" ],
+    bar    => [ "\N{BOX DRAWINGS HEAVY RIGHT}",
+		"\N{BOX DRAWINGS LIGHT HORIZONTAL}" ],
+    dash   => [ "\N{BOX DRAWINGS HEAVY RIGHT}",
+		"\N{BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL}" ],
+
+    arrow        => "\N{RIGHTWARDS ARROW}",
+    double_arrow => "\N{RIGHTWARDS DOUBLE ARROW}",
+    triple_arrow => "\N{RIGHTWARDS TRIPLE ARROW}",
+    white_arrow  => "\N{RIGHTWARDS WHITE ARROW}",
+    wave_arrow   => "\N{RIGHTWARDS WAVE ARROW}",
+    circle_arrow => "\N{CIRCLED HEAVY WHITE RIGHTWARDS ARROW}",
+    curved_arrow => "\N{HEAVY BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW}",
+    shadow_arrow => "\N{HEAVY UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW}",
+    squat_arrow  => "\N{SQUAT BLACK RIGHTWARDS ARROW}",
+    squiggle     => "\N{RIGHTWARDS SQUIGGLE ARROW}",
+    harpoon      => "\N{RIGHTWARDS HARPOON WITH BARB UPWARDS}",
+    cuneiform    => "\N{CUNEIFORM SIGN TAB}",
+
     );
 
 sub new {
@@ -156,8 +183,16 @@ sub configure {
 	my($a, $b) = splice @_, 0, 2;
 
 	if ($a eq 'tabstyle') {
-	    my $style = $tab_style{$b} or croak "$b: invalid tabstyle";
-	    unshift @_, tabhead => $style->[0], tabspace => $style->[1];
+	    $b // next;
+	    my($h, $s) = $b =~ /([-\w]+)/g or croak "$b: invalid tabstyle";
+	    $s ||= $h;
+	    my %style = (
+		h => ($TABSTYLE{$h} or croak "$h: invalid tabstyle"),
+		s => ($TABSTYLE{$s} or croak "$s: invalid tabstyle"),
+		);
+	    unshift @_,
+		tabhead  => $style{h}->[0],
+		tabspace => $style{s}->[1];
 	    next;
 	}
 
@@ -178,8 +213,6 @@ sub pop_reset {
     @reset ? do { @color_stack = (); pop @reset } : '';
 }
 
-use List::Util qw(pairgrep);
-
 sub fold {
     my $obj = ref $_[0] ? $_[0] : do {
 	state $private = configure();
@@ -465,7 +498,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.0903
+Version 2.10
 
 =head1 SYNOPSIS
 
@@ -538,6 +571,9 @@ using default width with additional parameter:
 
     ($folded, $remain) = ansi_fold($text, undef, padding => 1);
 
+Some other easy-to-use interfaces are provided by sister module
+L<Text::ANSI::Fold::Util>.
+
 =head1 OBJECT INTERFACE
 
 You can create an object to hold parameters, which is effective during
@@ -713,12 +749,43 @@ characters.  Both are white space by default.
 =item B<tabstyle> => I<style>
 
 Set tab expansion style.  This parameter set both B<tabhead> and
-B<tabspace> at once according to the given style name.  Currently
-these names are available.
+B<tabspace> at once according to the given style name.  Each style has
+two values for tabhead and tabspace.
 
+If two style names are combined, like C<symbol,space>, use
+C<symbols>'s tabhead and C<space>'s tabspace.
+
+Currently these names are available.
+
+    space  => [ ' ', ' ' ],
     dot    => [ '.', '.' ],
-    symbol => [ "\N{SYMBOL FOR HORIZONTAL TABULATION}", ' ' ],
-    shade  => [ "\N{MEDIUM SHADE}", "\N{LIGHT SHADE}" ],
+    symbol => [ "\N{SYMBOL FOR HORIZONTAL TABULATION}",
+                "\N{SYMBOL FOR SPACE}" ],
+    shade  => [ "\N{MEDIUM SHADE}",
+                "\N{LIGHT SHADE}" ],
+    block  => [ "\N{LOWER ONE QUARTER BLOCK}",
+                "\N{LOWER ONE EIGHTH BLOCK}" ],
+    bar    => [ "\N{BOX DRAWINGS HEAVY RIGHT}",
+                "\N{BOX DRAWINGS LIGHT HORIZONTAL}" ],
+    dash   => [ "\N{BOX DRAWINGS HEAVY RIGHT}",
+                "\N{BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL}" ],
+
+Below are styles providing same character for both tabhead and
+tabspace.  Convert underscore (C<_>) to dash (C<->) like
+C<double-arrow>.
+
+    arrow        => "\N{RIGHTWARDS ARROW}",
+    double_arrow => "\N{RIGHTWARDS DOUBLE ARROW}",
+    triple_arrow => "\N{RIGHTWARDS TRIPLE ARROW}",
+    white_arrow  => "\N{RIGHTWARDS WHITE ARROW}",
+    wave_arrow   => "\N{RIGHTWARDS WAVE ARROW}",
+    circle_arrow => "\N{CIRCLED HEAVY WHITE RIGHTWARDS ARROW}",
+    curved_arrow => "\N{HEAVY BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW}",
+    shadow_arrow => "\N{HEAVY UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW}",
+    squat_arrow  => "\N{SQUAT BLACK RIGHTWARDS ARROW}",
+    squiggle     => "\N{RIGHTWARDS SQUIGGLE ARROW}",
+    harpoon      => "\N{RIGHTWARDS HARPOON WITH BARB UPWARDS}",
+    cuneiform    => "\N{CUNEIFORM SIGN TAB}",
 
 =back
 
